@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2021 Colin Ian King
+ * Copyright (C) 2021-2022 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,6 +18,8 @@
  *
  * Author: Colin Ian King <colin.i.king@gmail.com>
  */
+#define _GNU_SOURCE
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
@@ -32,7 +34,7 @@
  */
 extern json_object *json_object_new_int64(const int64_t) __attribute__((weak));
 
-static inline void j_obj_is_null(json_object *obj, const char *msg)
+static inline void j_obj_is_null(const json_object *obj, const char *msg)
 {
 	if (!obj)
 		health_check_out_of_memory(msg);
