@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2021 Colin Ian King
+ * Copyright (C) 2021-2022 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,9 +18,9 @@
  *
  * Author: Colin Ian King <colin.i.king@gmail.com>
  */
-
 #define _GNU_SOURCE
 
+#include <bsd/string.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
@@ -547,6 +547,7 @@ static inline int syscall_get_return(const pid_t pid, int *rc)
 		.iov_base = &regs
 	};
 
+	(void)memset(&regs, 0, sizeof(regs));
 	errno = 0;
 	io.iov_len = sizeof(struct aarch64_regs);
 	ptrace(PTRACE_GETREGSET, pid, NT_PRSTATUS, &io);
@@ -593,9 +594,9 @@ static int syscall_get_args(
 #elif defined (__x86_64__)
 	int i;
 	long cs;
-	int *regs;
-	static int regs32[] = { RBX, RCX, RDX, RSI, RDI, RBP };
-	static int regs64[] = { RDI, RSI, RDX, R10, R8,  R9 };
+	const int *regs;
+	static const int regs32[] = { RBX, RCX, RDX, RSI, RDI, RBP };
+	static const int regs64[] = { RDI, RSI, RDX, R10, R8,  R9 };
 
 	cs = ptrace(PTRACE_PEEKUSER, pid, 8*CS, NULL);
 	switch (cs) {
@@ -617,6 +618,7 @@ static int syscall_get_args(
 	int i;
 	struct pt_regs regs;
 
+	(void)memset(&regs, 0, sizeof(regs));
 	if (ptrace(PTRACE_GETREGS, pid, NULL, (void *)&regs) < 0)
 		return -1;
 
@@ -631,6 +633,7 @@ static int syscall_get_args(
 	};
 	int i;
 
+	(void)memset(&regs, 0, sizeof(regs));
 	errno = 0;
 	io.iov_len = sizeof(struct aarch64_regs);
 	ptrace(PTRACE_GETREGSET, pid, NT_PRSTATUS, &io);
@@ -671,7 +674,7 @@ static int syscall_get_args(
 static void syscall_name(const int syscall, char *name, const size_t len)
 {
 	if (syscall_valid(syscall) && (syscalls[syscall].name)) {
-		strncpy(name, syscalls[syscall].name, len);
+		strlcpy(name, syscalls[syscall].name, len);
 	} else {
 		/*  Don't know it */
 		snprintf(name, len, "SYS_NR_%d", syscall);
@@ -2102,13 +2105,19 @@ void syscall_dump_execve(double duration)
  *  syscall_timeout_to_human_time()
  *	convert timeout time into something human readable
  */
-static char *syscall_timeout_to_human_time(
+static const char *syscall_timeout_to_human_time(
 	const double timeout,
 	const bool end,
 	char *buffer,
 	const size_t len)
 {
-	char *units[] = { "sec", "msec", "usec", "nsec", "psec" };
+	static const char *units[] = {
+		"sec",
+		"msec",
+		"usec",
+		"nsec",
+		"psec"
+	};
 	int i;
 	double t = timeout;
 
@@ -2209,7 +2218,7 @@ void syscall_dump_pollers(json_object *j_tests, const double duration)
 	if (sorted.head) {
 		if (!(opt_flags & OPT_BRIEF)) {
 			double prev, bucket;
-			char tmp[64], *units;
+			char tmp[64];
 			double total_rate = 0.0;
 			uint64_t poll_infinite = 0, poll_zero = 0, count = 0;
 
@@ -2229,6 +2238,7 @@ void syscall_dump_pollers(json_object *j_tests, const double duration)
 					s->poll_infinite, s->poll_zero);
 				if (s->poll_count) {
 					char min_timeout[70], max_timeout[70], avg_timeout[70];
+					const char *units;
 
 					units = syscall_timeout_to_human_time(s->poll_min < 0.0 ? 0.0 : s->poll_min, false, tmp, sizeof(tmp));
 					snprintf(min_timeout, sizeof(min_timeout), "%s %-4s", tmp, units);
@@ -2281,7 +2291,7 @@ void syscall_dump_pollers(json_object *j_tests, const double duration)
 			printf(" %*s Process              Syscall            sec",
 				pid_size, "PID");
 			for (bucket = BUCKET_START, i = 0; i < MAX_BUCKET; i++, bucket *= 10.0) {
-				units = syscall_timeout_to_human_time(bucket, true, tmp, sizeof(tmp));
+				const char *units = syscall_timeout_to_human_time(bucket, true, tmp, sizeof(tmp));
 				printf(" %6s", units);
 			}
 			printf("   Wait\n");
